@@ -1,6 +1,8 @@
+## no critic: Modules::ProhibitAutomaticExportation
+
 package Text::sprintfn;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -8,7 +10,7 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT    = qw(sprintfn printfn);
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.090'; # VERSION
 
 our $distance  = 10;
 
@@ -125,18 +127,19 @@ sub printfn {
 1;
 # ABSTRACT: Drop-in replacement for sprintf(), with named parameter support
 
-
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Text::sprintfn - Drop-in replacement for sprintf(), with named parameter support
 
 =head1 VERSION
 
-version 0.06
+This document describes version 0.090 of Text::sprintfn (from Perl distribution Text-sprintfn), released on 2019-11-19.
 
 =head1 SYNOPSIS
 
@@ -162,6 +165,65 @@ version 0.06
 This module provides sprintfn() and printfn(), which are like sprintf() and
 printf(), with the exception that they support named parameters from a hash.
 
+=head1 RATIONALE
+
+There exist other CPAN modules for string formatting with named parameter
+support. Two of such modules are L<String::Formatter> and
+L<Text::Sprintf::Named>. This module is far simpler to use and retains all of
+the features of Perl's sprintf() (which we like, or perhaps hate, but
+nevertheless are familiar with).
+
+String::Formatter requires you to create a new formatter function first.
+Text::Sprintf::Named also accordingly requires you to instantiate an object
+first. There is currently no way to mix named and positional parameters. And you
+don't get the full features of sprintf().
+
+=head1 HOW IT WORKS
+
+Text::sprintfn works by converting the format string into sprintf format, i.e.
+replacing the named parameters like C<%(foo)s> to something like C<%11$s>.
+
+=head1 DOWNSIDES
+
+Currently the main downside is speed. C<sprintfn()> is about 2-3 orders of
+magnitude slower than C<sprintf()>. See L<Bencher::Scenario::Textsprintfn> for
+benchmarks.
+
+=head1 TIPS AND TRICKS
+
+=head2 Common mistake 1
+
+Writing
+
+ %(var)
+
+instead of
+
+ %(var)s
+
+=head2 Common mistake 2 (a bit more newbish)
+
+Writing
+
+ sprintfn $format, %hash, ...;
+
+instead of
+
+ sprintfn $format, \%hash, ...;
+
+=head2 Alternative hashes
+
+You have several hashes (%h1, %h2, %h3) which should be consulted for values.
+You can either merge the hash first:
+
+ %h = (%h1, %h2, %h3); # or use some hash merging module
+ printfn $format, \%h, ...;
+
+or create a tied hash which can consult hashes for you:
+
+ tie %h, 'Your::Module', \%h1, \%h2, \%h3;
+ printfn $format, \%h, ...;
+
 =head1 FUNCTIONS
 
 =head2 sprintfn $fmt, \%hash, ...
@@ -205,74 +267,21 @@ There is currently no way to escape ")" in named parameter, e.g.:
 
 Equivalent to: print sprintfn($fmt, ...).
 
-=head1 RATIONALE
+=head1 HOMEPAGE
 
-There exist other CPAN modules for string formatting with named parameter
-support. Two of such modules are L<String::Formatter> and
-L<Text::Sprintf::Named>. This module is far simpler to use and retains all of
-the features of Perl's sprintf() (which we like, or perhaps hate, but
-nevertheless are familiar with).
+Please visit the project's homepage at L<https://metacpan.org/release/Text-sprintfn>.
 
-String::Formatter requires you to create a new formatter function first.
-Text::Sprintf::Named also accordingly requires you to instantiate an object
-first. There is currently no way to mix named and positional parameters. And you
-don't get the full features of sprintf().
+=head1 SOURCE
 
-=head1 HOW IT WORKS
+Source repository is at L<https://github.com/perlancar/perl-Text-sprintfn>.
 
-Text::sprintfn works by converting the format string into sprintf format, i.e.
-replacing the named parameters like C<%(foo)s> to something like C<%11$s>.
+=head1 BUGS
 
-=head1 DOWNSIDES
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-sprintfn>
 
-Currently the main downside is speed. On my computer, sprintfn() is about two
-orders of magnitude slower than plain sprintf(). A simple benchmark on my PC
-(Core i5-2400 @ 3.1GHz):
-
- $ bench -MText::sprintfn -n -2 'sprintf("%s %d %d", "one", 2, 3)' 'sprintfn("%(str)s %d %d", {str=>"one"}, 2, 3)'
- Benchmarking a => sub { sprintf("%s %d %d", "one", 2, 3) }, b => sub { sprintfn("%(str)s %d %d", {str=>"one"}, 2, 3) } ...
- a: 13666654 calls (6831551/s), 2.001s (0.0001ms/call)
- b: 72461 calls (35045/s), 2.068s (0.0285ms/call)
- Fastest is a (194.9x b)
-
-=head1 TIPS AND TRICKS
-
-=head2 Common mistake 1
-
-Writing
-
- %(var)
-
-instead of
-
- %(var)s
-
-=head2 Common mistake 2 (a bit more newbish)
-
-Writing
-
- sprintfn $format, %hash, ...;
-
-instead of
-
- sprintfn $format, \%hash, ...;
-
-=head2 Alternative hashes
-
-You have several hashes (%h1, %h2, %h3) which should be consulted for values.
-You can either merge the hash first:
-
- %h = (%h1, %h2, %h3); # or use some hash merging module
- printfn $format, \%h, ...;
-
-or create a tied hash which can consult hashes for you:
-
- tie %h, 'Your::Module', \%h1, \%h2, \%h3;
- printfn $format, \%h, ...;
-
-=head1 TODOS
-
-Some sort of caching.
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 SEE ALSO
 
@@ -284,14 +293,13 @@ L<Text::Sprintf::Named>
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2019, 2015, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
